@@ -19,12 +19,14 @@ LOGGER_DEFAULT_HANDLER.setFormatter(
 )
 
 LOGGER_DAEMON: logging.Logger = logging.getLogger('Tracers Daemon')
-LOGGER_DAEMON.addHandler(LOGGER_DAEMON_HANDLER)
 LOGGER_DAEMON.setLevel(logging.INFO)
+if not LOGGER_DAEMON.hasHandlers():
+    LOGGER_DAEMON.addHandler(LOGGER_DAEMON_HANDLER)
 
 LOGGER_DEFAULT: logging.Logger = logging.getLogger('Tracers')
-LOGGER_DEFAULT.addHandler(LOGGER_DEFAULT_HANDLER)
 LOGGER_DEFAULT.setLevel(logging.INFO)
+if not LOGGER_DEFAULT.hasHandlers():
+    LOGGER_DEFAULT.addHandler(LOGGER_DEFAULT_HANDLER)
 
 LOOP_CHECK_INTERVAL: float = 0.01
 LOOP_SKEW_TOLERANCE: float = 1.0
